import argparse
import json
import urllib.request

PARSER = argparse.ArgumentParser(description='Fetch metadata about a pip package')
PARSER.add_argument('package')


def main():
    args = PARSER.parse_args()
    # Fetch the package metadata: curl https://pypi.org/pypi/tensorflow/json
    # use urllib
    package = args.package
    url = f"https://pypi.org/pypi/{package}/json"
    with urllib.request.urlopen(url) as response:
        package_data = response.read().decode('utf-8')
        print(json.dumps(json.loads(package_data), indent=2))



import setuptools
import distutils.core

setuptools.setup(
    name='pip-show-json',
    version="1.0.2",
    author='readwithai',
    long_description_content_type='text/markdown',
    url='https://github.com/talwrii/pip-show',
    author_email='talwrii@gmail.com',
    description='pip show is broken. pip-show-json fetches json metadata.',
    license='MIT',
    packages=["pip_show"],
    long_description=open('README.md').read(),
    entry_points={
        'console_scripts': ['pip-show-json=pip_show.main:main']
    }
)
